@@ -36,7 +36,6 @@ tiny_data_sets = [
 "Tiny data sets."
 
 
-
 small_data_sets = [
     'T00759-tiny',
     'T00759-small',
@@ -46,52 +45,50 @@ small_data_sets = [
 "Small data sets."
 
 
-
 large_data_sets = [
     'T00759',
     'T99002',
     'T99003',
     'T99004',
     'T99005',
-    'T99006',    
+    'T99006',
 ]
 "Large data sets."
 
 
 encode_data_sets = [
-    'SRF'    , #   700Kb - see Jaspar
-    'ZBTB33' , #  1600Kb - see UniProbe
-    'RXRA'   , #  8000Kb - see UniProbe
-    'TCF12'  , # 13000Kb - see UniProbe
-    'CTCF'   , # 13700Kb - see Jaspar
+    'SRF',  # 700Kb - see Jaspar
+    'ZBTB33',  # 1600Kb - see UniProbe
+    'RXRA',  # 8000Kb - see UniProbe
+    'TCF12',  # 13000Kb - see UniProbe
+    'CTCF',  # 13700Kb - see Jaspar
 ]
 "Larger data sets from ENCODE."
 
 
-
 fasta_filenames = {
-    'T00759-tiny' : os.path.join(fasta_dir, 'T00759-tiny.fa'),
-    'T00759-small' : os.path.join(fasta_dir, 'T00759-small.fa'),
-    'dm01r' : os.path.join(fasta_dir, 'dm01r.fasta'),
-    'yst09m' : os.path.join(fasta_dir, 'yst09m.fasta'),
-    'T00671' : '/home/john/Data/GappedPssms/apr-2009/T00671trimRM.fa',
-    'T00759' : '/home/john/Data/GappedPssms/apr-2009/T00759trimRM.fa',
-    'T99002' : '/home/john/Data/GappedPssms/apr-2009/T99002trimRM.fa',
-    'T99003' : '/home/john/Data/GappedPssms/apr-2009/T99003trimRM.fa',
-    'T99004' : '/home/john/Data/GappedPssms/apr-2009/T99004trimRM.fa',
-    'T99005' : '/home/john/Data/GappedPssms/apr-2009/T99005trimRM.fa',
-    'T99006' : '/home/john/Data/GappedPssms/apr-2009/T99006trimRM.fa',
-    'SRF'    : '/home/john/Data/ENCODE/TF-ChIP/peaks/peaks-SRF.fa',
-    'ZBTB33' : '/home/john/Data/ENCODE/TF-ChIP/peaks/peaks-ZBTB33.fa',
-    'RXRA'   : '/home/john/Data/ENCODE/TF-ChIP/peaks/peaks-RXRA.fa',
-    'TCF12'  : '/home/john/Data/ENCODE/TF-ChIP/peaks/peaks-TCF12.fa',
-    'CTCF'   : '/home/john/Data/ENCODE/TF-ChIP/peaks/peaks-CTCF.fa',
+    'T00759-tiny': os.path.join(fasta_dir, 'T00759-tiny.fa'),
+    'T00759-small': os.path.join(fasta_dir, 'T00759-small.fa'),
+    'dm01r': os.path.join(fasta_dir, 'dm01r.fasta'),
+    'yst09m': os.path.join(fasta_dir, 'yst09m.fasta'),
+    'T00671': '/home/john/Data/GappedPssms/apr-2009/T00671trimRM.fa',
+    'T00759': '/home/john/Data/GappedPssms/apr-2009/T00759trimRM.fa',
+    'T99002': '/home/john/Data/GappedPssms/apr-2009/T99002trimRM.fa',
+    'T99003': '/home/john/Data/GappedPssms/apr-2009/T99003trimRM.fa',
+    'T99004': '/home/john/Data/GappedPssms/apr-2009/T99004trimRM.fa',
+    'T99005': '/home/john/Data/GappedPssms/apr-2009/T99005trimRM.fa',
+    'T99006': '/home/john/Data/GappedPssms/apr-2009/T99006trimRM.fa',
+    'SRF': '/home/john/Data/ENCODE/TF-ChIP/peaks/peaks-SRF.fa',
+    'ZBTB33': '/home/john/Data/ENCODE/TF-ChIP/peaks/peaks-ZBTB33.fa',
+    'RXRA': '/home/john/Data/ENCODE/TF-ChIP/peaks/peaks-RXRA.fa',
+    'TCF12': '/home/john/Data/ENCODE/TF-ChIP/peaks/peaks-TCF12.fa',
+    'CTCF': '/home/john/Data/ENCODE/TF-ChIP/peaks/peaks-CTCF.fa',
 }
 "The filenames of the FASTA files for the data sets."
 
 
 starts = {
-    'T00759-tiny' : [
+    'T00759-tiny': [
         ('AAAATA', 2, 13.15),
         ('AATTTA', 4, 30.45),
         ('GGAGGA', 8, 57.26),
@@ -113,7 +110,7 @@ starts = {
         ('TCACCTGTGACTCGG', 16, 103.62),
         ('CTAGTCAGAGTAAAC', 20, 117.82),
     ],
-    'T00759-small' : [
+    'T00759-small': [
         ('AAAAAA', 2, 13.04),
         ('AAAAAA', 4, 30.24),
         ('AAAAAT', 8, 64.64),
@@ -139,7 +136,7 @@ starts = {
         ('CCTCCTCTCTCCCTG', 32, 248.18),
         ('CCTCCTCTCTCCCTG', 50, 334.39),
     ],
-    'dm01r' : [
+    'dm01r': [
         ('CCCGGC', 2, 14.64),
         ('CCGGCG', 4, 33.45),
         ('CAGCGC', 8, 68.28),
@@ -161,7 +158,7 @@ starts = {
         ('GCGCCGCCGCCGCCG', 16, 170.41),
         ('CGCCGCCGCCGCCGA', 20, 179.56),
     ],
-    'yst09m' : [
+    'yst09m': [
         ('CCGCCG', 2, 15.59),
         ('CCGCCG', 4, 35.34),
         ('CCGCCG', 8, 74.70),
@@ -187,7 +184,7 @@ starts = {
         ('AGAAGAACAAGAAAG', 32, 245.39),
         ('AATTTTCTGTCGTTG', 50, 336.60),
     ],
-     'T00759' : [
+    'T00759': [
         ('AAAAAAAT', 2, 1.86),
         ('AAAAAAAT', 4, 1.86),
         ('AAAAAAAT', 8, 5.45),
@@ -225,7 +222,7 @@ starts = {
         ('CTCCCTXXXXXXXXXXXXXX', 256, 1.01),
         ('TCCTGCCCCGCCCCCTCCTC', 500, 1.37),
     ],
-    'T99002' : [
+    'T99002': [
         ('AAAAAAAA', 2, 8.96),
         ('AAAAAAAA', 4, 8.96),
         ('AAAAAAAA', 8, 8.96),
@@ -263,7 +260,7 @@ starts = {
         ('GCATTCTGGGAATTGTAGTT', 256, 0.00),
         ('GACTACAACTCCCAGAAGGC', 500, 0.00),
     ],
-    'T99003' : [
+    'T99003': [
         ('AAAAAAAA', 2, 6.32),
         ('AAAAAAAA', 4, 6.32),
         ('AAAAAAAA', 8, 4.15),
@@ -301,7 +298,7 @@ starts = {
         ('GGCGCTGTCCTCGGTGCTGA', 256, 0.00),
         ('GGCGCTGTCCATGGTGCTGA', 500, 0.00),
     ],
-    'T99004' : [
+    'T99004': [
         ('AAAAAAAA', 2, 1.54),
         ('AAAAAAAA', 4, 1.54),
         ('AAAAAAAA', 8, 2.36),
@@ -339,7 +336,7 @@ starts = {
         ('TGGTGCCCCCTGGTGGCCAA', 256, 1.16),
         ('XXXXXXXXXXXTTCTGGAAA', 500, 0.00),
     ],
-    'T99005' : [
+    'T99005': [
         ('CCCCCCCC', 2, 9.38),
         ('CCCCGCCC', 4, 2.29),
         ('CCCACCCC', 8, 6.19),
@@ -377,7 +374,7 @@ starts = {
         ('AAAGGATTTCTCAGAAAAGA', 256, 0.00),
         ('GATTTCTTAGAAATGAGCTC', 500, 0.00),
     ],
-    'T99006' : [
+    'T99006': [
         ('CCCCGCCC', 2, 2.06),
         ('CCCCGCCC', 4, 4.19),
         ('CCTGGAAC', 8, 3.21),
@@ -415,7 +412,7 @@ starts = {
         ('TTCTGAGAAAAGGAAGAAAA', 256, 1.71),
         ('XXXXXXXXXXXXXXXXXCAG', 500, 1.24),
     ],
-   'SRF' : [
+    'SRF': [
         ('AAAAAAAA', 2, 553.49),
         ('AAAGGAAA', 4, 7342.66),
         ('CCATATAA', 8, 0.49),
@@ -449,7 +446,7 @@ starts = {
         ('TGTCTTTGCTTTGCTTCCAC', 64, 1809588.61),
         ('CCATATAAGGCAGTGAACTT', 128, 12.18),
     ],
-    'ZBTB33' : [
+    'ZBTB33': [
         ('AAAAAAAT', 2, 2569925.90),
         ('AAAAACTA', 4, 6.02),
         ('AATGGAAT', 8, 3.47),
@@ -487,7 +484,7 @@ starts = {
         ('CCTAACCCTAACCCTCACCC', 256, 3.12),
         ('TCTCCACCCTTATCACAACA', 500, 0.00),
     ],
-    'RXRA' : [
+    'RXRA': [
         ('AAAAAAAA', 2, 1388.79),
         ('AAAAAAAA', 4, 287.95),
         ('AATGGAAT', 8, 5.14),
@@ -524,7 +521,7 @@ starts = {
         ('ACCCAGGGGTCACGGCTGTG', 128, 6.60),
         ('CATGGCTGTGTGGTGGGGGC', 256, 4.09),
     ],
-    'TCF12' : [
+    'TCF12': [
         ('AATTTTAT', 2, 1667471.52),
         ('AACAAAAA', 4, 82311.21),
         ('AATGGAAT', 8, 3.99),
@@ -560,7 +557,7 @@ starts = {
         ('CCCTCTTGCTTGCAGTGTAG', 128, 5.85),
         ('CCCTCTTGCTCACAGTATAG', 256, 4.47),
     ],
-    'CTCF' : [
+    'CTCF': [
         ('AAAAAATT', 2, 35682.52),
         ('AAAATAAT', 4, 68708.09),
         ('AGTGTAGT', 8, 5.87),
@@ -603,7 +600,8 @@ starts = {
 @cachedmethod
 def get_data_set_size(data_set):
     "@return: # seqs, # bases."
-    import corebio.seq, corebio.seq_io.fasta_io as F
+    import corebio.seq
+    import corebio.seq_io.fasta_io as F
     alphabet = corebio.seq.reduced_nucleic_alphabet
     num_bases = num_seqs = 0
     for seq in F.iterseq(
@@ -613,15 +611,20 @@ def get_data_set_size(data_set):
         num_seqs += 1
         num_bases += len(seq)
     return num_seqs, num_bases
-        
+
+
 def get_num_w_mers(data_set, W):
     "@return: # W-mers in the data set."
     num_seqs, num_bases = get_data_set_size(data_set)
     return num_bases - num_seqs * (W - 1)
 
+
 def add_options(parser):
-    parser.add_option("-d", "--data-sets", action="append", help="Run on this data set.")
-    parser.add_option("-g", "--groups", action="append", help="Run on this data set group.")
+    parser.add_option(
+        "-d", "--data-sets", action="append", help="Run on this data set.")
+    parser.add_option(
+        "-g", "--groups", action="append", help="Run on this data set group.")
+
 
 def data_sets_for_options(options):
     if options.data_sets:
@@ -632,4 +635,3 @@ def data_sets_for_options(options):
         for group in options.groups:
             data_set_names.update(eval('%s_data_sets' % group))
     return data_set_names
-
